mouseCursor property
The cursor shown when a pointer hovers over the container (web / desktop). If null, SystemMouseCursors.click is used while the container is enabled.
Implementation
final MouseCursor? mouseCursor;
The cursor shown when a pointer hovers over the container (web / desktop). If null, SystemMouseCursors.click is used while the container is enabled.
final MouseCursor? mouseCursor;