ContainerDecoration class

Constructors

ContainerDecoration({Color? backgroundColor, BorderRadius borderRadius = BorderRadius.zero, EdgeInsets padding = EdgeInsets.zero, EdgeInsets margin = EdgeInsets.zero, Alignment? alignment, BlendMode? backgroundBlendMode, List<BoxShadow>? boxShadow, BoxBorder? border, Gradient? gradient, InteractiveInkFeatureFactory? splashFactory, Color? splashColor, Color? highlightColor, Color? hoverColor, Color? focusColor, MouseCursor? mouseCursor})
const

Properties

alignment Alignment?
alignment positions the child within the RippleContainer.
final
backgroundBlendMode BlendMode?
final
backgroundColor Color?
backgroundColor Sets the background color of the RippleContainer.
final
border BoxBorder?
final
borderRadius BorderRadius
The borderRadius determines the border radius of the Container, and the child is clipped to fit the Container. default value is BorderRadius.zero
final
boxShadow List<BoxShadow>?
The boxShadow variable is used to apply a shadow outside the Container.
final
focusColor Color?
The color shown while the container has input focus. If null, the theme's focus color is used.
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
The highlight color shown while the container is pressed.
final
hoverColor Color?
The color shown while a pointer is hovering over the container (web / desktop). If null, the theme's hover color is used.
final
margin EdgeInsets
final
mouseCursor MouseCursor?
The cursor shown when a pointer hovers over the container (web / desktop). If null, SystemMouseCursors.click is used while the container is enabled.
final
padding EdgeInsets
padding is applied inside the Container, while margin is the value used to create space outside the Container. default value is EdgeInsets.zero.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
The splash color of the ink response. If this property is null then the splash color of the theme, ThemeData.splashColor, will be used.
final
splashFactory InteractiveInkFeatureFactory?
Defines the appearance of the splash.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited