decoration property
decoration is a value used to decorate the RippleContainer Widget. If null is provided, it behaves like a Container Widget that supports tap and long-press actions while still showing the ripple effect.
Implementation
final ContainerDecoration? decoration;